summaryrefslogtreecommitdiffstats
path: root/klaptopdaemon/buttons.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'klaptopdaemon/buttons.cpp')
-rw-r--r--klaptopdaemon/buttons.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/klaptopdaemon/buttons.cpp b/klaptopdaemon/buttons.cpp
index 3c05359..4c4c65d 100644
--- a/klaptopdaemon/buttons.cpp
+++ b/klaptopdaemon/buttons.cpp
@@ -4,7 +4,7 @@
* Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
* Copyright (c) 2002 Marc Mutz <mutz@kde.org>
*
* Requires the Qt widget libraries, available at no cost at
* http://www.troll.no/
*
* This program is free software; you can redistribute it and/or modify
@@ -44,8 +44,8 @@
#include <tqtooltip.h>
extern void wake_laptop_daemon();
-ButtonsConfig::ButtonsConfig (TQWidget * parent, const char *name)
- : KCModule(parent, name),
+ButtonsConfig::ButtonsConfig (TQWidget * tqparent, const char *name)
+ : KCModule(tqparent, name),
lidBox(0),
lidStandby(0),
lidSuspend(0),
@@ -120,7 +120,7 @@ ButtonsConfig::ButtonsConfig (TQWidget * parent, const char *name)
if (laptop_portable::has_button(laptop_portable::LidButton)) {
lidBox = new TQVButtonGroup(i18n("Lid Switch Closed"), this);
- lidBox->layout()->setSpacing( KDialog::spacingHint() );
+ lidBox->tqlayout()->setSpacing( KDialog::spacingHint() );
TQToolTip::add( lidBox, i18n( "Select which actions will occur when the laptop's lid is closed" ) );
hlay->addWidget( lidBox );
@@ -196,7 +196,7 @@ ButtonsConfig::ButtonsConfig (TQWidget * parent, const char *name)
if (laptop_portable::has_button(laptop_portable::PowerButton)) {
powerBox = new TQVButtonGroup(i18n("Power Switch Pressed"), this);
- powerBox->layout()->setSpacing( KDialog::spacingHint() );
+ powerBox->tqlayout()->setSpacing( KDialog::spacingHint() );
TQToolTip::add( powerBox, i18n( "Select which actions will occur when the laptop's power button is pressed" ) );
hlay->addWidget( powerBox );
@@ -273,12 +273,12 @@ ButtonsConfig::ButtonsConfig (TQWidget * parent, const char *name)
"or power switch on your laptop is pressed. Some laptops may already "
"automatically do things like this, if you cannot disable them in your BIOS "
"you probably should not enable anything in this panel."), this);
- explain->setAlignment( Qt::WordBreak );
+ explain->tqsetAlignment( TQt::WordBreak );
top_layout->addWidget(explain);
top_layout->addStretch(1);
- top_layout->addWidget( new TQLabel( i18n("Version: %1").arg(LAPTOP_VERSION), this ), 0, Qt::AlignRight );
+ top_layout->addWidget( new TQLabel( i18n("Version: %1").tqarg(LAPTOP_VERSION), this ), 0, TQt::AlignRight );
}
}
@@ -4,7 +4,7 @@
* Copyright (c) 2002 Marc Mutz <mutz@kde.org>
*
- * Requires the Qt widget libraries, available at no cost at
+ * Requires the TQt widget libraries, available at no cost at
* http://www.troll.no/
*